**Example 1: 关联子设备产品和网关产品**

关联子设备产品和网关产品

Input: 

```
tccli iot AssociateSubDeviceToGatewayProduct --cli-unfold-argument  \
    --SubDeviceProductId iot-4e0wsxpi \
    --GatewayProductId iot-43e0wsxas
```

Output: 
```
{
    "Response": {
        "RequestId": "b78d722c-c32c-4108-b9d8-a75be705e227"
    }
}
```

